@@ -20,11 +20,13 @@
 
 #include "gameactions.h"
 
-#include <KLocale>
-#include <KAction>
-#include <KActionCollection>
+#include <QAction>
+#include <QKeySequence>
 #include <QSignalMapper>
 
+#include <KActionCollection>
+#include <KLocalizedString>
+
 namespace ksudoku {
 
 GameActions::GameActions(KActionCollection* collection) {
@@ -50,95 +52,94 @@ void GameActions::init() {
 	const Qt::Key extras[] = {Qt::Key_0, Qt::Key_Slash, Qt::Key_Minus,
                             /* Qt::Key_Asterisk, */ Qt::Key_Plus, Qt::Key_Space,
 			    Qt::Key_Return};
-	KAction* a;
-	KShortcut shortcut;
+	QAction * a;
+	QList<QKeySequence> shortcuts;
 	for(int i = 0; i < 31; ++i) {
-		a = new KAction(this);
+		shortcuts.clear();
+		a = new QAction(this);
 		m_collection->addAction(QString("val-select%1").arg(i+1,2,10,QChar('0')), a);
 		a->setText(i18n("Select %1 (%2)", QChar('a'+i), i+1));
 		m_selectValueMapper->setMapping(a, i+1);
 		connect(a, SIGNAL(triggered(bool)), m_selectValueMapper, SLOT(map()));
 		m_actions << a;
 
-		a = new KAction(this);
+		a = new QAction(this);
 		m_collection->addAction(QString("val-enter%1").arg(i+1,2,10,QChar('0')), a);
 		a->setText(i18n("Enter %1 (%2)", QChar('a'+i), i+1));
-		shortcut = a->shortcut();
-		if (i < 25) {;
-		    // Keys A to Y, for Sudoku puzzles.
-		    shortcut.setPrimary( Qt::Key_A + i);
+		if (i < 25) {
+			// Keys A to Y, for Sudoku puzzles.
+			shortcuts << QKeySequence(Qt::Key_A + i);
 		}
 		else {
-		    // Extras for keying in Mathdoku and Killer Sudoku puzzles.
-		    shortcut.setPrimary (extras[i - 25]);
+			// Extras for keying in Mathdoku and Killer Sudoku puzzles.
+			shortcuts << QKeySequence(extras[i - 25]);
 		}
-		if(i < 9) {
-		    // Keys 1 to 9, for puzzles of order 9 or less.
-		    shortcut.setAlternate( Qt::Key_1 + i);
+		if (i < 9) {
+			// Keys 1 to 9, for puzzles of order 9 or less.
+			shortcuts << QKeySequence(Qt::Key_1 + i);
 		}
-		a->setShortcut(shortcut);
+		m_collection->setDefaultShortcuts(a, shortcuts);
 		m_enterValueMapper->setMapping(a, i+1);
 		connect(a, SIGNAL(triggered(bool)), m_enterValueMapper, SLOT(map()));
 		m_actions << a;
 		if (i >= 25) {
-		    continue;
+			continue;
 		}
 
-		a = new KAction(this);
+		shortcuts.clear();
+		a = new QAction(this);
 		m_collection->addAction(QString("val-mark%1").arg(i+1,2,10,QChar('0')), a);
 		a->setText(i18n("Mark %1 (%2)", QChar('a'+i), i+1));
-		shortcut = a->shortcut();
-		shortcut.setPrimary( QKeySequence(Qt::ShiftModifier | Qt::Key_A + i));
+		shortcuts << QKeySequence(Qt::ShiftModifier | (Qt::Key_A + i));
 		if(i < 9) {
-			shortcut.setAlternate( QKeySequence(Qt::ShiftModifier | Qt::Key_1 + i));
+			shortcuts << QKeySequence(Qt::ShiftModifier | (Qt::Key_1 + i));
 		}
-		a->setShortcut(shortcut);
+		m_collection->setDefaultShortcuts(a, shortcuts);
 		m_markValueMapper->setMapping(a, i+1);
 		connect(a, SIGNAL(triggered(bool)), m_markValueMapper, SLOT(map()));
 		m_actions << a;
 	}
 	
-	a = new KAction(this);
+	a = new QAction(this);
 	m_collection->addAction("move_up", a);
 	a->setText(i18n("Move Up"));
-	a->setShortcut(Qt::Key_Up);
+	m_collection->setDefaultShortcut(a, Qt::Key_Up);
 	connect(a, SIGNAL(triggered(bool)), SLOT(moveUp()));
 	m_actions << a;
 
-	a = new KAction(this);
+	a = new QAction(this);
 	m_collection->addAction("move_down", a);
 	a->setText(i18n("Move Down"));
-	a->setShortcut(Qt::Key_Down);
+	m_collection->setDefaultShortcut(a, Qt::Key_Down);
 	connect(a, SIGNAL(triggered(bool)), SLOT(moveDown()));
 	m_actions << a;
 
-	a = new KAction(this);
+	a = new QAction(this);
 	m_collection->addAction("move_left", a);
 	a->setText(i18n("Move Left"));
-	a->setShortcut(Qt::Key_Left);
+	m_collection->setDefaultShortcut(a, Qt::Key_Left);
 	connect(a, SIGNAL(triggered(bool)), SLOT(moveLeft()));
 	m_actions << a;
 
-	a = new KAction(this);
+	a = new QAction(this);
 	m_collection->addAction("move_right", a);
 	a->setText(i18n("Move Right"));
-	a->setShortcut(Qt::Key_Right);
+	m_collection->setDefaultShortcut(a, Qt::Key_Right);
 	connect(a, SIGNAL(triggered(bool)), SLOT(moveRight()));
 	m_actions << a;
 
-	a = new KAction(this);
+	a = new QAction(this);
 	m_collection->addAction("move_clear_cell", a);
 	a->setText(i18n("Clear Cell"));
-	shortcut = a->shortcut();
-	shortcut.setPrimary(Qt::Key_Backspace);
-	shortcut.setAlternate(Qt::Key_Delete);
-	a->setShortcut(shortcut);
+	m_collection->setDefaultShortcuts(a, QList<QKeySequence>()
+		<< QKeySequence(Qt::Key_Backspace)
+		<< QKeySequence(Qt::Key_Delete));
 	connect(a, SIGNAL(triggered(bool)), SLOT(clearValue()));
 	m_actions << a;
 }
 
 void GameActions::associateWidget(QWidget* widget) {
-	QVector<KAction*>::iterator it;
+	QVector<QAction *>::iterator it;
 	for(it = m_actions.begin(); it != m_actions.end(); ++it) {
 		widget->addAction(*it);
 	}
@@ -166,4 +167,4 @@ void GameActions::moveRight() {
 
 }
 
-#include "gameactions.moc"
+
